==> kvlibsdk_5_27_776.tar.gz: kvlibsdk/doc/HTMLhelp/search/all_10.js <==
var searchData=
[
  ['status_20codes',['Status Codes',['../group__can__status__codes.html',1,'']]],
  ['signals',['Signals',['../group__kvadb__signals.html',1,'']]],
  ['system_20information',['System Information',['../group__kvm__system__information.html',1,'']]],
  ['status_20codes',['Status Codes',['../group__lin__status__codes.html',1,'']]],
  ['send_20database_20signal',['Send database signal',['../page_example_c_gensig.html',1,'page_user_guide_kvadblib_samples']]],
  ['sendmessage_2ec',['SendMessage.c',['../page_tutorial_c_sendmessage.html',1,'page_tutorial']]],
  ['sendmessage_2ecs',['SendMessage.cs',['../page_tutorial_csharp_sendmessage.html',1,'page_tutorial']]],
  ['sample_20programs_20_28canlib_29',['Sample Programs (CANlib)',['../page_user_guide_canlib_samples.html',1,'page_canlib']]],
  ['sample_20programs_20_28kvadblib_29',['Sample Programs (kvaDBLib)',['../page_user_guide_kvadblib_samples.html',1,'page_kvadblib']]],
  ['sample_20programs_20_28kvrlib_29',['Sample Programs (kvrlib)',['../page_user_guide_kvrlib_samples.html',1,'']]],
  ['send_20and_20receive_20can_20messages',['Send and Receive CAN Messages',['../page_user_guide_send_recv.html',1,'page_canlib']]],
  ['serialnumber',['serialNumber',['../structkvm_log_version_ex.html#a1f36efa76fac084b62745c8e8ed0a751',1,'kvmLogVersionEx']]],
  ['start_5fpos',['start_pos',['../structtag__token.html#a9715e2df77829e54cb078a298fd6c434',1,'tag_token']]],
  ['status',['status',['../structcan_notify_data.html#a345c20017f48fbb3fb2b3adada292f29',1,'canNotifyData']]],
  ['stddata',['stdData',['../structcan_bus_statistics__s.html#a45656d1d249afb1ef001b9d56337b26b',1,'canBusStatistics_s']]],
  ['stdremote',['stdRemote',['../structcan_bus_statistics__s.html#adbc105164238a47be6d13a16cfdf07d8',1,'canBusStatistics_s']]],
  ['support_2etxt',['support.txt',['../support_8txt.html',1,'']]],
  ['synchbreaklength',['synchBreakLength',['../struct_lin_message_info.html#a137ad7080687a2011666ac9eafe0832f',1,'LinMessageInfo']]],
  ['synchedgetime',['synchEdgeTime',['../struct_lin_message_info.html#a2eb7b88360a5994c5a4f49f02138c0f0',1,'LinMessageInfo']]]
];

==> kvlibsdk_5_28_846.tar.gz: kvlibsdk/doc/HTMLhelp/search/all_10.js <==
var searchData=
[
  ['status_20codes',['Status Codes',['../group__can__status__codes.html',1,'']]],
  ['signals',['Signals',['../group__kvadb__signals.html',1,'']]],
  ['system_20information',['System Information',['../group__kvm__system__information.html',1,'']]],
  ['status_20codes',['Status Codes',['../group__lin__status__codes.html',1,'']]],
  ['send_20database_20signal',['Send database signal',['../page_example_c_gensig.html',1,'page_user_guide_kvadblib_samples']]],
  ['sendmessage_2ec',['SendMessage.c',['../page_tutorial_c_sendmessage.html',1,'page_tutorial']]],
  ['sendmessage_2ecs',['SendMessage.cs',['../page_tutorial_csharp_sendmessage.html',1,'page_tutorial']]],
  ['sample_20programs_20_28canlib_29',['Sample Programs (CANlib)',['../page_user_guide_canlib_samples.html',1,'page_canlib']]],
  ['sample_20programs_20_28kvadblib_29',['Sample Programs (kvaDBLib)',['../page_user_guide_kvadblib_samples.html',1,'page_kvadblib_user_guide_intro']]],
  ['sample_20programs_20_28kvrlib_29',['Sample Programs (kvrlib)',['../page_user_guide_kvrlib_samples.html',1,'']]],
  ['send_20and_20receive_20can_20messages',['Send and Receive CAN Messages',['../page_user_guide_send_recv.html',1,'page_canlib']]],
  ['serialnumber',['serialNumber',['../structkvm_log_version_ex.html#a1f36efa76fac084b62745c8e8ed0a751',1,'kvmLogVersionEx']]],
  ['start_5fpos',['start_pos',['../structtag__token.html#a9715e2df77829e54cb078a298fd6c434',1,'tag_token']]],
  ['status',['status',['../structcan_notify_data.html#a345c20017f48fbb3fb2b3adada292f29',1,'canNotifyData']]],
  ['stddata',['stdData',['../structcan_bus_statistics__s.html#a45656d1d249afb1ef001b9d56337b26b',1,'canBusStatistics_s']]],
  ['stdremote',['stdRemote',['../structcan_bus_statistics__s.html#adbc105164238a47be6d13a16cfdf07d8',1,'canBusStatistics_s']]],
  ['support_2etxt',['support.txt',['../support_8txt.html',1,'']]],
  ['synchbreaklength',['synchBreakLength',['../struct_lin_message_info.html#a137ad7080687a2011666ac9eafe0832f',1,'LinMessageInfo']]],
  ['synchedgetime',['synchEdgeTime',['../struct_lin_message_info.html#a2eb7b88360a5994c5a4f49f02138c0f0',1,'LinMessageInfo']]]
];
